MetaboLabPy
============
|Version| |Py versions| |Git| |Bioconda| |Build Status (Travis)| |Build Status (AppVeyor)| |License| |RTD doc| |codecov|

Python package to process 1D and 2D NMR spectroscopic data for metabolomics and tracer based metabolism analysis

- **Documentation:** https://ludwigc.github.io/metabolabpy
- **Source:** https://github.com/ludwigc/MetaboLabPy
- **Bug reports:** https://github.com/ludwigc/MetaboLabPy/issues

Installation
------------
See the `Installation page <https://ludwigc.github.io/metabolabpy/introduction.html#installation>`__ of
the `online documentation <https://ludwigc.github.io/metabolabpy/>`__.


Command line
------------
::

    $ metabolabpy --help


Bugs
----
Please report any bugs that you find `here <https://github.com/ludwigc/MetaboLabPy/issues>`_.
Or fork the repository on `GitHub <https://github.com/ludwigc/MetaboLabPy/>`_
and create a pull request (PR). We welcome all contributions, and we
will help you to make the PR if you are new to `git`.


Developers & Contributors
-------------------------
 - Christian Ludwig (C.Ludwig@bham.ac.uk) - `University of Birmingham (UK) <http://www.birmingham.ac.uk/index.aspx>`_


License
-------
Released under the GNU General Public License v3.0 (see `LICENSE file <https://github.com/ludwigc/metabolabpy/blob/master/LICENSE>`_)


.. |Build Status (Travis)| image:: https://img.shields.io/travis/ludwigc/metabolabpy.svg?style=flat&maxAge=3600&label=Travis-CI
   :target: https://travis-ci.org/ludwigc/metabolabpy

.. |Build Status (AppVeyor)| image:: https://img.shields.io/appveyor/ci/ludwigc/metabolabpy.svg?style=flat&maxAge=3600&label=AppVeyor
   :target: https://ci.appveyor.com/project/ludwigc/metabolabpy/branch/master

.. |Py versions| image:: https://img.shields.io/pypi/pyversions/metabolabpy.svg?style=flat&maxAge=3600
   :target: https://pypi.python.org/pypi/metabolabpy/

.. |Version| image:: https://img.shields.io/pypi/v/metabolabpy.svg?style=flat&maxAge=3600
   :target: https://pypi.python.org/pypi/metabolabpy/

.. |Git| image:: https://img.shields.io/badge/repository-GitHub-blue.svg?style=flat&maxAge=3600
   :target: https://github.com/ludwigc/metabolabpy

.. |Bioconda| image:: https://img.shields.io/badge/install%20with-bioconda-brightgreen.svg?style=flat&maxAge=3600
   :target: http://bioconda.github.io/recipes/metabolabpy/README.html

.. |License| image:: https://img.shields.io/pypi/l/metabolabpy.svg?style=flat&maxAge=3600
   :target: https://www.gnu.org/licenses/gpl-3.0.html

.. |RTD doc| image:: https://img.shields.io/badge/documentation-RTD-71B360.svg?style=flat&maxAge=3600
   :target: https://metabolabpy.readthedocs.io/en/latest/
   
.. |codecov| image:: https://codecov.io/gh/ludwigc/metabolabpy/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/ludwigc/metabolabpy

.. |binder| image:: https://mybinder.org/badge_logo.svg
   :target: https://mybinder.org/v2/gh/ludwigc/metabolabpy/master?filepath=notebooks%2Fworkflow.ipynb
